from django import template

register = template.Library()


@register.inclusion_tag('gaston/menu.html', takes_context=True)
def menu(context, menu):
    return {
        'menu': menu,
        'request': context['request'],
    }


@register.filter()
def get_partial_path(path):
    if path == '/':
        return path
    else:
        split_path = path.split('/')
        return ('/' + split_path[1] + '/')



import setuptools

with open('README.md', 'r') as f:
    long_description = f.read()

setuptools.setup(
    name='django-gaston',
    version='0.0.5',
    author='Hyde Tek',
    description='A django menu generator',
    long_description=long_description,
    packages=setuptools.find_packages(),
    python_requires='>=3.6',
)
